=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2010-03-08 02:23:17 +0000
+++ bzrlib/builtins.py	2010-03-13 02:49:14 +0000
@@ -5143,7 +5143,7 @@
                short_name='f',
                type=unicode),
         Option('output', short_name='o',
-               help='Write merge directive to this file; '
+               help='Write merge directive to this file or directory; '
                     'use - for stdout.',
                type=unicode),
         Option('strict',

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2010-03-13 02:05:22 +0000
+++ bzrlib/merge_directive.py	2010-03-13 02:49:14 +0000
@@ -69,10 +69,15 @@
 
     This is the base class that all merge directive implementations 
     should derive from.
+
+    :cvar multiple_output_files: Whether or not this merge directive 
+        stores a set of revisions in more than one file
     """
 
     hooks = MergeDirectiveHooks()
 
+    multiple_output_files = False
+
     def __init__(self, revision_id, testament_sha1, time, timezone,
                  target_branch, patch=None, source_branch=None, message=None,
                  bundle=None):
@@ -104,6 +109,13 @@
         """
         raise NotImplementedError(self.to_lines)
 
+    def to_files(self):
+        """Serialize as a set of files.
+
+        :return: List of tuples with filename and contents as lines
+        """
+        raise NotImplementedError(self.to_files)
+
     def get_raw_bundle(self):
         """Return the bundle for this merge directive.
 
@@ -130,6 +142,13 @@
         lines.append('# \n')
         return lines
 
+    def write_to_directory(self, path):
+        """Write this merge directive to a series of files in a directory.
+
+        :param path: Filesystem path to write to
+        """
+        raise NotImplementedError(self.write_to_directory)
+
     @classmethod
     def from_objects(klass, repository, revision_id, time, timezone,
                  target_branch, patch_type='bundle',

=== modified file 'bzrlib/send.py'
--- bzrlib/send.py	2010-02-10 02:17:15 +0000
+++ bzrlib/send.py	2010-03-13 02:49:14 +0000
@@ -15,6 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
+import os
 import time
 
 from bzrlib import (
@@ -134,15 +135,29 @@
             directive.compose_merge_request(mail_client, mail_to, body,
                                             branch, tree)
         else:
-            if output == '-':
-                outfile = to_file
+            if directive.multiple_output_files:
+                if output == '-':
+                    raise errors.BzrCommandError('- not supported for '
+                        'merge directives that use more than one output file.')
+                if not os.path.exists(output):
+                    os.mkdir(output, 0755)
+                for (filename, lines) in directive.to_files():
+                    path = os.path.join(output, filename)
+                    outfile = open(path, 'wb')
+                    try:
+                        outfile.writelines(lines)
+                    finally:
+                        outfile.close()
             else:
-                outfile = open(output, 'wb')
-            try:
-                outfile.writelines(directive.to_lines())
-            finally:
-                if outfile is not to_file:
-                    outfile.close()
+                if output == '-':
+                    outfile = to_file
+                else:
+                    outfile = open(output, 'wb')
+                try:
+                    outfile.writelines(directive.to_lines())
+                finally:
+                    if outfile is not to_file:
+                        outfile.close()
     finally:
         branch.unlock()
 

